| nimbleType-class | R Documentation |
Create a nimbleType object, with information on the name, type, and dimension of an object to be placed in a nimbleList.
This function creates nimbleType objects, which can be used to define the elements of a nimbleList.
The type argument can be chosen from among character, double, integer, and logical,
or can be the name of a previously created nimbleList definition.
See the NIMBLE User Manual for additional examples.
NIMBLE development team
nimbleTypeList <- list()
nimbleTypeList[[1]] <- nimbleType(name = 'x', type = 'integer', dim = 0)
nimbleTypeList[[2]] <- nimbleType(name = 'Y', type = 'double', dim = 2)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.